# Effects

Visual, color, distortion, and light effects that can be applied to clips.

## Base

::: pymotion.effects.base.Effect

## Visual Effects

::: pymotion.effects.visual.GaussianBlur

::: pymotion.effects.visual.Bloom

::: pymotion.effects.visual.ChromaticAberration

::: pymotion.effects.visual.FilmGrain

::: pymotion.effects.visual.Glow

::: pymotion.effects.visual.LensFlare

::: pymotion.effects.visual.MotionBlur

::: pymotion.effects.visual.Sharpen

::: pymotion.effects.visual.Vignette

## Color Effects

::: pymotion.effects.color.Brightness

::: pymotion.effects.color.Contrast

::: pymotion.effects.color.Saturation

::: pymotion.effects.color.ColorBalance

::: pymotion.effects.color.HueSaturationLuminance

::: pymotion.effects.color.Curves

::: pymotion.effects.color.LUTEffect

::: pymotion.effects.color.SplitToning

::: pymotion.effects.color.BleachBypass

## Distortion Effects

::: pymotion.effects.distortion.Fisheye

::: pymotion.effects.distortion.Twirl

::: pymotion.effects.distortion.Ripple

::: pymotion.effects.distortion.WaveWarp

::: pymotion.effects.distortion.PerspectiveWarp

## Light Effects

::: pymotion.effects.light.NeonGlow

::: pymotion.effects.light.GodRays

::: pymotion.effects.light.LensFlareLight

::: pymotion.effects.light.LightLeak
